==> fishsupper-0.1.3.tar.gz: fishsupper-0.1.3/src/settings.h <==
//  Fish Supper
//  Copyright (C) 2006 Matthew Clarke <matthew_larcke@lycos.co.uk>
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
// 
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
//  02111-1307, USA.




#ifndef _SETTINGS_H_
#define _SETTINGS_H_




#include <iostream>
#include <fstream>
#include <string>
#include <cstdlib>




extern bool joystick_available;
extern char * fs_dir;




namespace FS
{

class Settings
{
    private:
            
        bool fullscreen;
        bool joystick_selected;
        bool sound;
        
    public:
            
        Settings();
        ~Settings();
        
        void read_config_file();
        void write_config_file(bool _joystick_selected, bool _sound, 
                bool _fullscreen);
        
        bool is_joystick_available() const { return joystick_available; }
        bool is_fullscreen() const { return fullscreen; }
        bool is_joystick_selected() const { return joystick_selected; }
        bool is_sound() const { return sound; }
        
        void print_settings() const;
        
}; // class Settings

} // namespace FS




#endif

==> fishsupper-0.1.4.tar.gz: fishsupper-0.1.4/src/settings.h <==
// $Id: settings.h,v 1.4 2006/08/05 09:08:59 matthew Exp $

//  Fish Supper
//  Copyright (C) 2006 Matthew Clarke <matthew_larcke@lycos.co.uk>
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
// 
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
//  02111-1307, USA.




#ifndef _SETTINGS_H_
#define _SETTINGS_H_




#include <iostream>
#include <fstream>
#include <string>
#include <cstdlib>




extern bool joystick_available;
extern char * fs_dir;




namespace FS
{

class Settings
{
    private:
            
        bool fullscreen;
        bool joystick_selected;
        bool sound;
        int furthest_level;
        
    public:
            
        Settings();
        ~Settings();
        
        void read_config_file();
        void write_config_file();
        
        bool is_joystick_available() const { return joystick_available; }
        bool is_fullscreen() const { return fullscreen; }
        bool is_joystick_selected() const { return joystick_selected; }
        bool is_sound() const { return sound; }
        int get_furthest_level() const { return furthest_level; }
        
        void set_fullscreen(bool b) { fullscreen = b; }
        void set_joystick_selected(bool b) { joystick_selected = b; }
        void set_sound(bool b) { sound = b; }
        void set_furthest_level(int lev);
        
        void print_settings() const;
        
}; // class Settings

} // namespace FS




#endif
